@@ -1,13 +1,14 @@
 #########################################
 #### A Shiny App for UCSC Xena ##########
 #########################################
-##### LICENSE: MIT @Openbiox   ##########
+##### LICENSE: GPLv3 @Openbiox   ##########
 #########################################
 
 
 #' Run UCSC Xena Shiny App
 #'
 #' @importFrom shiny shinyAppFile
+#' @inheritParams shiny::runApp
 #' @param runMode default is 'client' for personal user, set it to 'server' for running on server.
 #' @return NULL
 #' @export
@@ -16,8 +17,9 @@
 #' \dontrun{
 #' app_run()
 #' }
-app_run <- function(runMode = "client") {
+app_run <- function(runMode = "client", port = getOption("shiny.port")) {
   runMode <- match.arg(runMode, choices = c("client", "server"))
   options(xena.runMode = runMode)
-  shiny::shinyAppFile(system.file("shinyapp", "App.R", package = "UCSCXenaShiny"))
+  shiny::shinyAppFile(system.file("shinyapp", "App.R", package = "UCSCXenaShiny"),
+                      options = list(port = port))
 }
